[`src/plasmapy/`]: .
[**coding guide**]: https://docs.plasmapy.org/en/latest/contributing/coding_guide.html
[contributor guide]: https://docs.plasmapy.org/en/latest/contributing
[`tests/`]: ../../tests
[`docs/`]: ../../docs

# PlasmaPy Source Code

The [`src/plasmapy/`] directory contains PlasmaPy's source code. The
corresponding tests are in the top-level [`tests/`] directory, with
documentation in the top-level [`docs/`] directory.

> [!TIP]
> For more information on writing Python code in PlasmaPy, please see
> the [**coding guide**] in PlasmaPy's [contributor guide].
